==> qt-creator-2.2.0-src.zip: qt-creator-2.2.0-src/src/plugins/qmldesigner/symbianplugin/symbianplugin.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#ifndef SymbianPLUGIN_H
#define SymbianPLUGIN_H

#include <iwidgetplugin.h>
#include <QtDeclarative/qdeclarative.h>

QT_BEGIN_NAMESPACE
QT_END_NAMESPACE

namespace QmlDesigner {

class SymbianPlugin : public QObject, QmlDesigner::IWidgetPlugin
{
    Q_OBJECT
    Q_DISABLE_COPY(SymbianPlugin)
    Q_INTERFACES(QmlDesigner::IWidgetPlugin)
public:
    SymbianPlugin();
    ~SymbianPlugin() {}

    QString metaInfo();
    QString pluginName();

};

} // namespace QmlDesigner


#endif // SymbianPLUGIN_H

==> qt-creator-2.5.1-src.zip: qt-creator-2.5.1-src/src/plugins/qmldesigner/symbianplugin/symbianplugin.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#ifndef SymbianPLUGIN_H
#define SymbianPLUGIN_H

#include <iwidgetplugin.h>
#include <qdeclarative.h>

namespace QmlDesigner {

class SymbianPlugin : public QObject, QmlDesigner::IWidgetPlugin
{
    Q_OBJECT
    Q_INTERFACES(QmlDesigner::IWidgetPlugin)

public:
    SymbianPlugin();

    QString metaInfo() const;
    QString pluginName() const;
};

} // namespace QmlDesigner

#endif // SymbianPLUGIN_H
